/***************************************************************************
 *   Copyright (C) 2008 by Tim Nugent
 *   timnugent@gmail.com
 *
 *   This file is part of hugin.
 *
 *   Hugin is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 2 of the License, or
 *   (at your option) any later version.
 * 
 *   Hugin is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with Hugin  If not, see <http://www.gnu.org/licenses/>.
 *
 ***************************************************************************/

#ifndef GLOBALS_H
#define GLOBALS_H
#include <hugin_shared.h>

extern bool kSaveFilter;
extern bool kVerbosity;
extern IMPEX int gRadius;
extern IMPEX float gS;
extern IMPEX int gA;
extern IMPEX int gF;
extern IMPEX float gL;
extern IMPEX float gU;	
extern IMPEX int gNumLocs;
extern IMPEX int **gLocations;
extern IMPEX int spacing;
extern IMPEX int resize_dimension;

#endif

